@@ -33,7 +33,7 @@ class PACProbabilisticTeacher(ProbabilisticTeacher):
         return self.__target_model.log_sequence_weight(sequence)
 
     def last_token_weights(self, sequence: Sequence, required_suffixes: list[Sequence]):
-        self._last_token_weight_queries_count +=1        
+        self._last_token_weight_queries_count +=len(required_suffixes)        
         return self.__target_model.get_last_token_weights(sequence, required_suffixes)
 
     def get_log_probability_error(self, seq, aut: WeightedAutomaton):
