@@ -20,9 +20,9 @@ class TestPDFATeachersLStarCol(unittest.TestCase):
         teacher1 = PDFATeacher(model, 0, PDFAComparator())
         teacher2 = SampleProbabilisticTeacher(model, 0, sample_size=500, max_seq_length=20)
         teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, 0, max_seq_length=20)
-        result1 = self.learner.learn(teacher1)
-        result2 = self.learner.learn(teacher2)
-        result3 = self.learner.learn(teacher3)
+        result1 = self.learner.learn(teacher1, verbose = True)
+        result2 = self.learner.learn(teacher2, verbose = True)
+        result3 = self.learner.learn(teacher3, verbose = True)
         extracted_model1 = result1.model
         extracted_model2 = result2.model
         extracted_model3 = result3.model
@@ -35,9 +35,9 @@ class TestPDFATeachersLStarCol(unittest.TestCase):
         teacher1 = PDFATeacher(model, 0, PDFAComparator())
         teacher2 = SampleProbabilisticTeacher(model, 0, sample_size=500, max_seq_length=20)
         teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, 0, max_seq_length=20)
-        result1 = self.learner.learn(teacher1)
-        result2 = self.learner.learn(teacher2)
-        result3 = self.learner.learn(teacher3)
+        result1 = self.learner.learn(teacher1, verbose = True)
+        result2 = self.learner.learn(teacher2, verbose = True)
+        result3 = self.learner.learn(teacher3, verbose = True)
         extracted_model1 = result1.model
         extracted_model2 = result2.model
         extracted_model3 = result3.model
@@ -50,9 +50,9 @@ class TestPDFATeachersLStarCol(unittest.TestCase):
         teacher1 = PDFATeacher(model, 0, PDFAComparator())
         teacher2 = SampleProbabilisticTeacher(model, 0, sample_size=500, max_seq_length=20)
         teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, 0, max_seq_length=20)
-        result1 = self.learner.learn(teacher1)
-        result2 = self.learner.learn(teacher2)
-        result3 = self.learner.learn(teacher3)
+        result1 = self.learner.learn(teacher1, verbose = True)
+        result2 = self.learner.learn(teacher2, verbose = True)
+        result3 = self.learner.learn(teacher3, verbose = True)
         extracted_model1 = result1.model
         extracted_model2 = result2.model
         extracted_model3 = result3.model
@@ -65,9 +65,9 @@ class TestPDFATeachersLStarCol(unittest.TestCase):
         teacher1 = PDFATeacher(model, 0, PDFAComparator())
         teacher2 = SampleProbabilisticTeacher(model, 0, sample_size=500, max_seq_length=20)
         teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, 0, max_seq_length=20)
-        result1 = self.learner.learn(teacher1)
-        result2 = self.learner.learn(teacher2)
-        result3 = self.learner.learn(teacher3)
+        result1 = self.learner.learn(teacher1, verbose = True)
+        result2 = self.learner.learn(teacher2, verbose = True)
+        result3 = self.learner.learn(teacher3, verbose = True)
         extracted_model1 = result1.model
         extracted_model2 = result2.model
         extracted_model3 = result3.model        
@@ -81,9 +81,9 @@ class TestPDFATeachersLStarCol(unittest.TestCase):
         teacher1 = PDFATeacher(model, 0, PDFAComparator())
         teacher2 = SampleProbabilisticTeacher(model, 0, sample_size=500, max_seq_length=20)
         teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, 0, max_seq_length=20)
-        result1 = self.learner.learn(teacher1)
-        result2 = self.learner.learn(teacher2)
-        result3 = self.learner.learn(teacher3)
+        result1 = self.learner.learn(teacher1, verbose = True)
+        result2 = self.learner.learn(teacher2, verbose = True)
+        result3 = self.learner.learn(teacher3, verbose = True)
         extracted_model1 = result1.model
         extracted_model2 = result2.model
         extracted_model3 = result3.model        
@@ -96,9 +96,9 @@ class TestPDFATeachersLStarCol(unittest.TestCase):
         teacher1 = PDFATeacher(model, 0, PDFAComparator())
         teacher2 = SampleProbabilisticTeacher(model, 0, sample_size=500, max_seq_length=20)
         teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, 0, max_seq_length=20)
-        result1 = self.learner.learn(teacher1)
-        result2 = self.learner.learn(teacher2)
-        result3 = self.learner.learn(teacher3)
+        result1 = self.learner.learn(teacher1, verbose = True)
+        result2 = self.learner.learn(teacher2, verbose = True)
+        result3 = self.learner.learn(teacher3, verbose = True)
         extracted_model1 = result1.model
         extracted_model2 = result2.model
         extracted_model3 = result3.model
@@ -111,9 +111,9 @@ class TestPDFATeachersLStarCol(unittest.TestCase):
         teacher1 = PDFATeacher(model, 0, PDFAComparator())
         teacher2 = SampleProbabilisticTeacher(model, 0, sample_size=500, max_seq_length=20)
         teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, 0, max_seq_length=20)
-        result1 = self.learner.learn(teacher1)
-        result2 = self.learner.learn(teacher2)
-        result3 = self.learner.learn(teacher3)
+        result1 = self.learner.learn(teacher1, verbose = True)
+        result2 = self.learner.learn(teacher2, verbose = True)
+        result3 = self.learner.learn(teacher3, verbose = True)
         extracted_model1 = result1.model
         extracted_model2 = result2.model
         extracted_model3 = result3.model
